"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
/* eslint-env mocha */
const assert_1 = require("assert");
const index_js_1 = __importDefault(require("../index.js"));
// Test utils
const peerbit_test_utils_1 = require("@dao-xyz/peerbit-test-utils");
const globals_1 = require("@jest/globals");
Object.keys(peerbit_test_utils_1.testAPIs).forEach((IPFS) => {
    describe(`IO tests (${IPFS})`, function () {
        globals_1.jest.setTimeout(10000);
        let ipfs, ipfsd;
        beforeAll(async () => {
            ipfsd = await (0, peerbit_test_utils_1.startIpfs)(IPFS, peerbit_test_utils_1.nodeConfig);
            ipfs = ipfsd.api;
        });
        afterAll(async () => {
            await (0, peerbit_test_utils_1.stopIpfs)(ipfsd);
        });
        describe('dag-cbor', () => {
            let cid1, cid2;
            const data = { test: 'object' };
            it('writes', async () => {
                cid1 = await index_js_1.default.write(ipfs, 'dag-cbor', data, { pin: true });
                expect(cid1).toEqual('zdpuAwHevBbd7V9QXeP8zC1pdb3HmugJ7zgzKnyiWxJG3p2Y4');
                let obj = await index_js_1.default.read(ipfs, cid1, {});
                assert_1.strict.deepStrictEqual(obj, data);
                data[cid1] = cid1;
                cid2 = await index_js_1.default.write(ipfs, 'dag-cbor', data, { links: [cid1] });
                expect(cid2).toEqual('zdpuAqeyAtvp1ACxnWZLPW9qMEN5rJCD9N3vjUbMs4AAodTdz');
                obj = await index_js_1.default.read(ipfs, cid2, { links: [cid1] });
                data[cid1] = cid1;
                assert_1.strict.deepStrictEqual(obj, data);
            });
        });
        describe('dag-pb', () => {
            let cid;
            const data = { test: 'object' };
            it('writes', async () => {
                cid = await index_js_1.default.write(ipfs, 'dag-pb', data, { pin: true });
                expect(cid).toEqual('QmaPXy3wcj4ds9baLreBGWf94zzwAUM41AiNG1eN51C9uM');
                const obj = await index_js_1.default.read(ipfs, cid, {});
                assert_1.strict.deepStrictEqual(obj, data);
            });
        });
        describe('raw', () => {
            let cid;
            const data = { test: 'object' };
            it('writes', async () => {
                cid = await index_js_1.default.write(ipfs, 'raw', data, { pin: true });
                expect(cid).toEqual('zdpuAwHevBbd7V9QXeP8zC1pdb3HmugJ7zgzKnyiWxJG3p2Y4');
                cid = await index_js_1.default.write(ipfs, 'raw', data, { format: 'dag-pb' });
                expect(cid).toEqual('QmaPXy3wcj4ds9baLreBGWf94zzwAUM41AiNG1eN51C9uM');
                const obj = await index_js_1.default.read(ipfs, cid, {});
                assert_1.strict.deepStrictEqual(obj, data);
            });
        });
    });
});
//# sourceMappingURL=io.test.js.map